from setuptools import setup

setup(name='class_file_Nikolay',
      version='0.3',
      description='удобный класс дял работы с файлом',
      packages=['class_file_Nikolay'],
      author_email='nikolajh913@gmail.com',
      zip_safe=False)


# Nikolay_1
# 147Nikolay1996
